@@ -1,35 +1,54 @@
 perm <-
-function (x, clu, rev, lbs) 
+function (x, clu, rev, lbs, sort) 
 {
     if (isTRUE(is.array(x) == TRUE) == FALSE && isTRUE(is.data.frame(x) == 
         TRUE) == FALSE && isTRUE(is.matrix(x) == TRUE) == FALSE) 
         stop("'x' must be an array, matrix, or a data frame object.")
-    if (missing(clu) == TRUE || isTRUE(length(unlist(clu)) != 
-        dim(x)[1]) == TRUE) 
-        stop("'clu' is missing or it does not match the order of 'x'.")
+    if (missing(sort) == FALSE && (missing(clu) == FALSE || missing(rev) == 
+        FALSE || missing(lbs) == FALSE)) 
+        warning("Values in \"clu\", \"rev\", and \"lbs\" are ignored by activating \"sort\".")
     ifelse(missing(rev) == FALSE && isTRUE(rev == TRUE) == TRUE, 
         rev <- TRUE, rev <- FALSE)
-    if (is.character(clu) == TRUE || is.factor(clu) == TRUE) {
-        tmp <- as.vector(clu)
-        for (i in seq_len(nlevels(factor(clu)))) {
-            tmp[which(levels(factor(clu))[i] == tmp)] <- i
+    if (missing(sort) == TRUE && (missing(clu) == TRUE || isTRUE(length(unlist(clu)) != 
+        dim(x)[1]) == TRUE)) 
+        stop("'clu' is missing or it does not match the order of 'x'.")
+    if (missing(sort) == FALSE && is.null(dimnames(x)) == TRUE) 
+        return(x)
+    if (missing(sort) == FALSE && isTRUE(sort == TRUE) == TRUE && 
+        is.null(dimnames(x)) == FALSE) {
+        clu <- vector()
+        lb <- dimnames(x)[[1]]
+        for (i in seq(length(lb))) {
+            clu <- append(clu, which(sort(lb) %in% lb[i]))
         }
         rm(i)
-        cls <- as.numeric(tmp)
-        rm(tmp)
-    }
-    else if (is.numeric(clu) == TRUE) {
-        ifelse(isTRUE(0L %in% as.numeric(levels(factor(clu)))) == 
-            TRUE, cls <- clu + 1L, cls <- clu)
-    }
-    else if (is.data.frame(clu) == TRUE || is.list(clu) == TRUE) {
-        cls <- as.vector(unlist(clu))
-    }
-    else {
         cls <- clu
     }
-    ifelse(NA %in% cls, cls[which(is.na(cls))] <- max(as.numeric(levels(factor(cls)))) + 
-        1L, NA)
+    else if (missing(sort) == TRUE | is.null(dimnames(x)) == 
+        TRUE) {
+        if (is.character(clu) == TRUE || is.factor(clu) == TRUE) {
+            tmp <- as.vector(clu)
+            for (i in seq_len(nlevels(factor(clu)))) {
+                tmp[which(levels(factor(clu))[i] == tmp)] <- i
+            }
+            rm(i)
+            cls <- as.numeric(tmp)
+            rm(tmp)
+        }
+        else if (is.numeric(clu) == TRUE) {
+            ifelse(isTRUE(0L %in% as.numeric(levels(factor(clu)))) == 
+                TRUE, cls <- clu + 1L, cls <- clu)
+        }
+        else if (is.data.frame(clu) == TRUE || is.list(clu) == 
+            TRUE) {
+            cls <- as.vector(unlist(clu))
+        }
+        else {
+            cls <- clu
+        }
+        ifelse(NA %in% cls, cls[which(is.na(cls))] <- max(as.numeric(levels(factor(cls)))) + 
+            1L, NA)
+    }
     or <- list()
     for (i in as.numeric(unique(cls))) {
         or[[i]] <- which(cls == i)
