@@ -1,14 +1,64 @@
 transf <-
-function (x, type = c("toarray", "tolist", "toarray2"), lbs = NULL, 
-    lb2lb, sep, ord, sort, sym, add, adc) 
+function (x, type = c("toarray", "tolist", "toarray2", "toedgel"), 
+    lbs = NULL, lb2lb, sep, ord, sort, sym, add, adc) 
 {
     ifelse(missing(sep) == TRUE, sep <- ", ", NA)
     ifelse(is.list(x) == TRUE && isTRUE(length(x) == 1L) == TRUE, 
         x <- x[[1]], NA)
-    if (match.arg(type) == "tolist") {
-        if (isTRUE(is.character(x) == TRUE) == TRUE | (is.array(x) == 
-            TRUE && is.null(dim(x)[3]) == TRUE)) 
+    if (match.arg(type) == "toarray" && is.data.frame(x) == TRUE) {
+        return(suppressWarnings(read.srt(x)))
+    }
+    if (match.arg(type) == "toedgel") {
+        if (is.array(x) == TRUE) {
+            if (is.na(dim(x)[3]) == TRUE) {
+                tmp <- trnf(x, tolist = TRUE, lb2lb = TRUE, lbs = dimnames(x)[[1]], 
+                  sep = sep)
+                tmp2 <- sapply(tmp, function(z) {
+                  strsplit(z, sep)
+                })
+                rm(tmp)
+                edgl <- data.frame(matrix(nrow = 0, ncol = 3))
+                colnames(edgl) <- c("s", "r", "t")
+                for (i in seq_len(length(tmp2))) {
+                  edgl[nrow(edgl) + 1L, ] <- c(strsplit(tmp2[[i]], 
+                    sep)[[1]], strsplit(tmp2[[i]], sep)[[2]], 
+                    "1")
+                }
+                rm(i)
+            }
+            else {
+                tmpl <- trnf(x, tolist = TRUE, lb2lb = TRUE, 
+                  lbs = dimnames(x)[[1]], sep = sep)
+                tmp <- trnf(x, tolist = TRUE, lb2lb = FALSE, 
+                  sep = sep)
+                tmp2 <- sapply(tmp, function(z) {
+                  strsplit(z, sep)
+                })
+                rm(tmp)
+                edgl <- data.frame(matrix(nrow = 0, ncol = (dim(x)[3]) + 
+                  2))
+                colnames(edgl) <- c("s", "r", dimnames(x)[[3]])
+                for (k in seq_len(dim(x)[3])) {
+                  for (l in seq_len(length(tmp2[[k]]))) {
+                    ifelse(isTRUE(length(unique(tmp2[[k]][l][[1]])) == 
+                      1) == TRUE, edgl[nrow(edgl) + 1L, (k + 
+                      2)] <- 1L, edgl[nrow(edgl) + 1L, (k + 2)] <- 1L)
+                    edgl[nrow(edgl), 1:2] <- strsplit(tmpl[[k]][[l]], 
+                      sep)[[1]]
+                  }
+                  rm(l)
+                }
+                rm(k)
+                edgl[sapply(edgl, is.na)] <- 0
+            }
+            return(edgl)
+        }
+        else {
+            warning("Only arrays in \"x\" are supported for 'toedgel' type option.")
             return(x)
+        }
+    }
+    if (match.arg(type) == "tolist") {
         if (is.array(x) == TRUE) {
             if (isTRUE(sum(x) > 0L) == FALSE | isTRUE(max(x) < 
                 1L) == TRUE) 
@@ -30,8 +80,10 @@ function (x, type = c("toarray", "tolist", "toarray2"), lbs = NULL,
             lbsr <- lbsc <- lbs
         }
         else {
-            lbsr <- dimnames(x)[[1]]
-            lbsc <- dimnames(x)[[2]]
+            ifelse(is.null(dimnames(x)[[1]]) == TRUE, lbsr <- seq_len(dim(x)[1]), 
+                lbsr <- dimnames(x)[[1]])
+            ifelse(is.null(dimnames(x)[[2]]) == TRUE, lbsr <- seq_len(dim(x)[2]), 
+                lbsc <- dimnames(x)[[2]])
         }
         rws <- vector()
         cls <- vector()
@@ -55,8 +107,7 @@ function (x, type = c("toarray", "tolist", "toarray2"), lbs = NULL,
             return(unlist(inc))
         }
         else {
-            Inc <- list()
-            length(Inc) <- dim(x)[3]
+            Inc <- vector("list", length = dim(x)[3])
             names(Inc) <- dimnames(x)[[3]]
             for (k in seq_len(dim(x)[3])) {
                 inc <- list()
@@ -138,7 +189,7 @@ function (x, type = c("toarray", "tolist", "toarray2"), lbs = NULL,
                 isTRUE(nlevels(factor(unlist(dhc(x, sep = sep)))) > 
                   ord) == TRUE) {
                 ord <- nlevels(factor(unlist(dhc(x, sep = sep))))
-                warning("'ord' is ignored, value is less than the number of factor levels in the pairwise list.")
+                warning("'ord' value is less than the number of factor levels in pairwise list and is ignored.")
             }
             else {
                 NA
@@ -190,7 +241,7 @@ function (x, type = c("toarray", "tolist", "toarray2"), lbs = NULL,
             mat <- matrix(0L, nrow = ord, ncol = ord)
         }
         else {
-            stop("Input for 'toarray' must be a vector, a list, ar an array.")
+            stop("Input for 'toarray' must be vector, pairwise list, edge list, or array.")
         }
         if (isTRUE(lb2lb == TRUE) == FALSE && is.null(lbs) == 
             TRUE) {
@@ -267,7 +318,7 @@ function (x, type = c("toarray", "tolist", "toarray2"), lbs = NULL,
                     0L)]
                   if (is.null(lbs) == FALSE) {
                     if (is.list(lbs) == FALSE) 
-                      warning("\"lbs\" should be a list with this option.")
+                      warning("\"lbs\" should be a list with this type option.")
                     vc1 <- unique(c(vec1[[k]], lbs[[k]][[1]]))
                     vc2 <- unique(c(vec2[[k]], lbs[[k]][[2]]))
                   }
@@ -303,7 +354,7 @@ function (x, type = c("toarray", "tolist", "toarray2"), lbs = NULL,
                   0L)]
                 if (is.null(lbs) == FALSE) {
                   if (is.list(lbs) == FALSE) 
-                    warning("\"lbs\" should be a list with this option.")
+                    warning("\"lbs\" should be a list with this type option.")
                   vc1 <- unique(c(vec1, lbs[[1]]))
                   vc2 <- unique(c(vec2, lbs[[2]]))
                 }
